@@ -215,3 +215,51 @@ num2col <- function(x, col.pal=heat.colors, reverse=FALSE,
     res[is.na(res)] <- na.col
     return(res)
 }
+
+
+
+
+
+###########
+## fac2col
+###########
+## translate a factor into colors of a palette
+## colors are randomized based on the provided seed
+fac2col <- function(x, col.pal=funky, na.col="grey", seed=1){
+    ## get factors and levels
+    x <- factor(x)
+    lev <- levels(x)
+    nlev <- length(lev)
+
+    ## get colors corresponding to levels
+    set.seed(seed)
+    newseed <- round(runif(1,1,1e9))
+    on.exit(set.seed(newseed))
+    col <- sample(col.pal(nlev))
+
+    ## get output colors
+    res <- rep(na.col, length(x))
+    res[!is.na(x)] <- col[as.integer(x[!is.na(x)])]
+
+    ## return
+    return(res)
+}
+
+
+## pre-defined palettes ##
+## mono color
+bluepal <- colorRampPalette(c("lightgrey","blue"))
+redpal <- colorRampPalette(c("lightgrey","red"))
+greenpal <- colorRampPalette(c("lightgrey","green"))
+
+## bi-color
+flame <- colorRampPalette(c("gold","red"))
+
+## tri-color
+seasun <- colorRampPalette(c("blue","gold","red"))
+lightseasun <- colorRampPalette(c("deepskyblue2","gold","red1"))
+deepseasun <- colorRampPalette(c("blue2","gold","red2"))
+
+## psychedelic
+funky <- colorRampPalette(c("blue","green3","gold","orange","red","brown4","purple"))
+
