@@ -19,7 +19,7 @@ glPlot <- function(x, col=NULL, legend=TRUE, posi="bottomleft", bg=rgb(1,1,1,.5)
     image(x=1:nLoc(x), y=1:nInd(x), z=X, xlab="SNP index", ylab="Individual index", yaxt="n", col=myCol, ...)
 
     ## add y axis
-    axis(side=2, at=nInd(x)-ylabpos+1, lab=ylabpos)
+    axis(side=2, at=nInd(x)-ylabpos+1, labels=ylabpos)
 
     ## add legend
     if(legend){
